==> checkout_core-0.0.73.crate: checkout_core-0.0.73/src/internal_context.rs <==
use cloud_pubsub::{Client, Subscription, Topic};
use std::sync::Arc;

use crate::error::{new_server_error, Error};

#[derive(Clone)]
pub struct InternalContext {
    pub pubsub_client: Arc<Client>,
    pub payment_processing_topic: Arc<Topic>,
    pub checkout_completion_topic: Arc<Topic>,
    pub payment_processing_subscription: Arc<Subscription>,
    pub checkout_completion_subscription: Arc<Subscription>,
}

impl InternalContext {
    pub async fn new(
        google_application_credentials: String,
        payment_processing_topic_name: String,
        checkout_completion_topic_name: String,
    ) -> Result<Self, Error> {
        let pubsub_client = Arc::new(
            cloud_pubsub::Client::new(google_application_credentials)
                .await
                .map_err(|_| new_server_error("failed to create pubsub client"))?,
        );

        let payment_processing_topic =
            Arc::new(pubsub_client.topic(payment_processing_topic_name.clone()));

        let checkout_completion_topic =
            Arc::new(pubsub_client.topic(checkout_completion_topic_name.clone()));

        let payment_processing_subscription =
            Arc::new(pubsub_client.subscribe(payment_processing_topic_name));

        let checkout_completion_subscription =
            Arc::new(pubsub_client.subscribe(checkout_completion_topic_name));

        Ok(Self {
            pubsub_client,
            payment_processing_topic,
            checkout_completion_topic,
            payment_processing_subscription,
            checkout_completion_subscription,
        })
    }
}

==> checkout_core-0.0.134.crate: checkout_core-0.0.134/src/internal_context.rs <==
use cloud_pubsub::{Client, Subscription, Topic};
use std::sync::Arc;

use crate::error::{new_server_error, Error};

#[derive(Clone)]
pub struct InternalContext {
    pub pubsub_client: Arc<Client>,
    pub payment_processing_topic: Arc<Topic>,
    pub payment_processing_subscription: Arc<Subscription>,
    pub order_events_topic: Arc<Topic>,
    pub order_events_subscription: Arc<Subscription>,
}

impl InternalContext {
    pub async fn new(
        google_application_credentials: String,
        payment_processing_topic_name: String,
        order_events_topic_name: String,
    ) -> Result<Self, Error> {
        let pubsub_client = Arc::new(
            cloud_pubsub::Client::new(google_application_credentials)
                .await
                .map_err(|_| new_server_error("failed to create pubsub client"))?,
        );

        let payment_processing_topic =
            Arc::new(pubsub_client.topic(payment_processing_topic_name.clone()));

        let payment_processing_subscription =
            Arc::new(pubsub_client.subscribe(payment_processing_topic_name));

        let order_events_topic = Arc::new(pubsub_client.topic(order_events_topic_name.clone()));

        let order_events_subscription = Arc::new(pubsub_client.subscribe(order_events_topic_name));

        Ok(Self {
            pubsub_client,
            payment_processing_topic,
            payment_processing_subscription,
            order_events_topic,
            order_events_subscription,
        })
    }
}
